@@ -63,10 +63,6 @@ class McModel(object):
                 t = cls.get(i)
                 if t:
                     t.mc_set()
-            else:
-                t = loads(t)
-                t = cls(*t)
-                t._new_record = False
             r[i] = t
         return r
 
